：<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        @headClick = "headClick"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        ref="stockInCodeTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form v-if="addOrUpdateVisible" ref="addOrUpdate" @refreshDataList="getData"></table-form>
    </basic-container>
  </div>
</template>

<script>
  import {fetchList, delObj} from '@/api/warehouse/stockincode'
  import TableForm from './stockincode-form'
  import {mapGetters} from 'vuex'
  import ttable from '@/views/common/ztt-table.vue';
  export default {
    data () {
      return {
        ajaxFun:fetchList,
        valueList:[],
        labelList:[],
        locTypeOptions:[],
        mulStockInCode: [],
        uploadInfo:{//是否展示上传EXCEL以及对应的url
          isShow:false,
          url:''
        },
        prelang:"operation",
        options: {
          height:300,//默认高度-为了表头固定
          stripe: true, // 是否为斑马纹 table
          highlightCurrentRow: false, // 是否要高亮当前行
          border:true,//是否有纵向边框
          lazy:false,//是否需要懒加载
          fit:true,//列的宽度是否自撑开
          multiSelect:true,//
          seqNo:true,
          isRefresh:true,//是否显示刷新按钮
          isShowHide:true,//是否显示显影按钮
          isSearch:false,//高级查询按钮
          defaultOrderBy:{column:'id',direction:'desc'}
        },
        table: {
          total: 0,
          currentPage: 1,
          pageSize: 20,
          data:[],
          // 标题
          column: [
            //原因码编号
            {minWidth:'140',prop:"stockCodeNo",label:"原因码编号",sort: true,isTrue:true,isSearch:true,searchInfoType:'text',render:{fun:this.addOrUpdateHandle}},
            //原因码类型
            {minWidth:'120',prop: "stockCodeType",label:"原因码类型",sort: true,isTrue:true,isSearch:true,searchInfoType:'select',optList:() => {return this.getStockCodeTypeOptionList()},formatter: (row, column, cellValue) => {return cellValue==1?'出库':'入库';}},
            //出入库原因码描述
            {minWidth:'200',prop: "stockCodeName",label:"出入库原因码描述",sort: true,isTrue:true,isSearch:true,searchInfoType:'text'},
            //启动状态
            {minWidth:'140',prop:"stockCodeStatus",label:"启动状态",sort: true,isTrue:true,isSearch:true,searchInfoType:'select',optList:() => {return this.getStockCodeStatusOptionList()},formatter: (row, column, cellValue) => {return cellValue==1?'启动':'停止';}},
            //备注
            {minWidth:'120',prop: "stockCodeRemark",label:"备注",sort: true,isTrue:true,formatter:this.locationType,isSearch:false,searchInfoType:'text'},
            //创建时间
            {minWidth:'200',width:'300',prop: "createTime",label:"创建时间",sort: true,isTrue:true,isSearch:true,searchInfoType:'datetimerange',formatter:this.showTime},
          ],
          toolbar: [
            {
              text: '新增',
              type: 'primary',
              fun: this.addOrUpdateHandle
            }
          ],
          operator:[
        {
          text: '删除',
          type: 'text',
          size: 'small',
          fun: this.deleteHandle
        }
          ],
          operatorConfig:{
            fixed:'right',
            label:'操作',
            width:100,
            minWidth:100
          }
        },
        addOrUpdateVisible: false,
        stockCodeTypeOptionList:[
          {
            value:1,
            label:'出库'
          },
          {
            value:0,
            label:'入库'
          }
        ],
        stockCodeStatusOptionList:[
          {
            value:1,
            label:'启动'
          },
          {
            value:0,
            label:'停止'
          }
        ]
      }
    },
    watch: {
      'this.labelList': {
        handler(newValue, oldValue) {
          if (newValue) {

          }
        },
        immediate: true
      }
    },
    components: {
      ttable,
      TableForm
    },
    computed: {
      ...mapGetters(['permissions'])
    },
    methods: {
      //选中仓库行
      handleSelectionChange(val) {
        this.mulStockInCode = val
      },
      // 获取数据列表
      getData () {
        this.$refs.stockInCodeTable.getDataList();
      },
      //表头的点击事件
      headClick(val){
        this.labelList.push(val.column.children[0].property)
        this.valueList.push(val.column.order)
      },
      getStockCodeTypeOptionList(){
        return this.stockCodeTypeOptionList;
      },
      getStockCodeStatusOptionList(){
        return this.stockCodeStatusOptionList;
      },
      // 新增 / 修改
      addOrUpdateHandle(row) {
        this.addOrUpdateVisible = true
        this.$nextTick(() => {
          this.$refs.addOrUpdate.init(row==null?null:row.id)
        })
      },
      showTime(row, column) {
        var date = row[column.property];
        if (date == undefined) {
          return "";
        }
        // 使用DD 如果使用dd 则变成 星期几 的英文缩写
        return moment(date).format("yyyy-MM-DD");},
      // 删除
      deleteHandle (row) {
        this.$confirm('是否确认删除原因码编号为' + row.stockCodeNo, '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          closeOnClickModal:false,
          type: 'warning'
        }).then(function () {
          return delObj(row.id)
        }).then(data => {
          this.$message.success('删除成功')
          this.getData()
        })
      }
    }
  }
</script>
